bars[![](https://docs.portainer.io/~gitbook/image?url=https%3A%2F%2F2279730396-files.gitbook.io%2F%7E%2Ffiles%2Fv0%2Fb%2Fgitbook-x-prod.appspot.com%2Fo%2Forganizations%252F-MgDK9ndL1-o2MHHFiXo%252Fsites%252Fsite_gbGqX%252Ficon%252FBp9XxrPYsEW8iW0CygKM%252FPortainer%2520-%2520P%2520Icon%2520SQUARE%2520-%2520Purple%2520%2526%2520Graphite.png%3Falt%3Dmedia%26token%3D34bdcf35-7fb8-4b6f-91cb-e9de8b772d04&width=32&dpr=3&quality=100&sign=eccdaaf2&sv=2)![](https://docs.portainer.io/~gitbook/image?url=https%3A%2F%2F2279730396-files.gitbook.io%2F%7E%2Ffiles%2Fv0%2Fb%2Fgitbook-x-prod.appspot.com%2Fo%2Forganizations%252F-MgDK9ndL1-o2MHHFiXo%252Fsites%252Fsite_gbGqX%252Ficon%252FFDKzZiw3rNqZ8FuFTT64%252FPortainer%2520-%2520P%2520Icon%2520SQUARE%2520-%2520Purple%2520%2526%2520Graphite.png%3Falt%3Dmedia%26token%3Dafbf7bd8-b9ce-4722-8101-90499e52f7fb&width=32&dpr=3&quality=100&sign=933f7d15&sv=2)Portainer Documentation](https://docs.portainer.io/)
search
circle-xmark
`⌘Ctrl``k`
[Official Website](https://portainer.io)[Pricing](https://www.portainer.io/pricing)[Get 3 Nodes of BE Free](https://www.portainer.io/get-a-license)
Moreellipsischevron-down
[![](https://docs.portainer.io/~gitbook/image?url=https%3A%2F%2F2279730396-files.gitbook.io%2F%7E%2Ffiles%2Fv0%2Fb%2Fgitbook-x-prod.appspot.com%2Fo%2Forganizations%252F-MgDK9ndL1-o2MHHFiXo%252Fsites%252Fsite_gbGqX%252Ficon%252FBp9XxrPYsEW8iW0CygKM%252FPortainer%2520-%2520P%2520Icon%2520SQUARE%2520-%2520Purple%2520%2526%2520Graphite.png%3Falt%3Dmedia%26token%3D34bdcf35-7fb8-4b6f-91cb-e9de8b772d04&width=32&dpr=3&quality=100&sign=eccdaaf2&sv=2)![](https://docs.portainer.io/~gitbook/image?url=https%3A%2F%2F2279730396-files.gitbook.io%2F%7E%2Ffiles%2Fv0%2Fb%2Fgitbook-x-prod.appspot.com%2Fo%2Forganizations%252F-MgDK9ndL1-o2MHHFiXo%252Fsites%252Fsite_gbGqX%252Ficon%252FFDKzZiw3rNqZ8FuFTT64%252FPortainer%2520-%2520P%2520Icon%2520SQUARE%2520-%2520Purple%2520%2526%2520Graphite.png%3Falt%3Dmedia%26token%3Dafbf7bd8-b9ce-4722-8101-90499e52f7fb&width=32&dpr=3&quality=100&sign=933f7d15&sv=2)Portainer Documentation](https://docs.portainer.io/)
2.39 LTSchevron-down
  * [Welcome](https://docs.portainer.io/)
  * [What's new in version 2.39](https://docs.portainer.io/whats-new)
  * [Release Notes](https://docs.portainer.io/release-notes)
  * Getting Started
    * [Introduction](https://docs.portainer.io/start/intro)
    * [Portainer architecture](https://docs.portainer.io/start/architecture)
    * [Lifecycle policy](https://docs.portainer.io/start/lifecycle)
    * [Requirements and prerequisites](https://docs.portainer.io/start/requirements-and-prerequisites)
    * [Install Portainer BEchevron-right](https://docs.portainer.io/start/install)
    * [Install Portainer CEchevron-right](https://docs.portainer.io/start/install-ce)
    * [Add an environment to an existing installation](https://docs.portainer.io/start/agent)
    * [Updating Portainerchevron-right](https://docs.portainer.io/start/upgrade)
  * Using Portainer
    * [Homechevron-right](https://docs.portainer.io/user/home)
    * [Docker/Swarm/Podmanchevron-right](https://docs.portainer.io/user/docker)
    * [Kuberneteschevron-right](https://docs.portainer.io/user/kubernetes)
    * [Azure ACIchevron-right](https://docs.portainer.io/user/aci)
    * [Nomad](https://docs.portainer.io/user/nomad)
    * [Edge Computechevron-right](https://docs.portainer.io/user/edge)
    * [Observabilitychevron-right](https://docs.portainer.io/user/observability)
    * [Account settings](https://docs.portainer.io/user/account-settings)
  * Administering Portainer
    * [User-relatedchevron-right](https://docs.portainer.io/admin/user)
    * [Environment-relatedchevron-right](https://docs.portainer.io/admin/environments)
    * [Registrieschevron-right](https://docs.portainer.io/admin/registries)
    * [Licenses](https://docs.portainer.io/admin/licenses)
    * [Logschevron-right](https://docs.portainer.io/admin/logs)
    * [Notifications](https://docs.portainer.io/admin/notifications)
    * [Settingschevron-right](https://docs.portainer.io/admin/settings)
  * Frequently Asked Questions
    * [Getting startedchevron-right](https://docs.portainer.io/faqs/getting-started)
    * [Installingchevron-right](https://docs.portainer.io/faqs/installing)
    * [Upgrading and downgradingchevron-right](https://docs.portainer.io/faqs/upgrading)
    * [Licensingchevron-right](https://docs.portainer.io/faqs/licensing)
    * [Troubleshootingchevron-right](https://docs.portainer.io/faqs/troubleshooting)
    * [Contributingchevron-right](https://docs.portainer.io/faqs/contributing)
    * [Known issueschevron-right](https://docs.portainer.io/faqs/known-issues)
    * [Getting supportchevron-right](https://docs.portainer.io/faqs/getting-support)
  * Advanced Topics
    * [CLI configuration options](https://docs.portainer.io/advanced/cli)
    * [App templateschevron-right](https://docs.portainer.io/advanced/app-templates)
    * [The Portainer Edge Agent](https://docs.portainer.io/advanced/edge-agent)
    * [Access control](https://docs.portainer.io/advanced/access-control)
    * [Reset the admin user's password](https://docs.portainer.io/advanced/reset-admin)
    * [Security and compliance](https://docs.portainer.io/advanced/security)
    * [Encrypting the Portainer database](https://docs.portainer.io/advanced/db-encryption)
    * [Using your own SSL certificate with Portainer](https://docs.portainer.io/advanced/ssl)
    * [Using mTLS with Portainer](https://docs.portainer.io/advanced/mtls)
    * [Stream auth and activity logs to an external provider](https://docs.portainer.io/advanced/siem)
    * [Using Portainer with reverse proxieschevron-right](https://docs.portainer.io/advanced/reverse-proxy)
    * [How Relative Path Support works in Portainer](https://docs.portainer.io/advanced/relative-paths)
    * [Helm chart configuration options](https://docs.portainer.io/advanced/helm-chart-configuration-options)
    * [Docker roles and permissions](https://docs.portainer.io/advanced/docker-roles-and-permissions)
    * [Kubernetes roles and bindings](https://docs.portainer.io/advanced/kubernetes-roles-and-bindings)
    * [Deprecated and removed features](https://docs.portainer.io/advanced/deprecated)
  * API
    * [Accessing the Portainer API](https://docs.portainer.io/api/access)
    * [API documentation](https://docs.portainer.io/api/docs)
    * [API usage examples](https://docs.portainer.io/api/examples)
  * Get More Help
    * [Portainer Academyarrow-up-right](https://academy.portainer.io)
    * [Slackarrow-up-right](https://portainer.io/slack)
    * [Discordarrow-up-right](https://portainer.io/discord)
    * [Open a support requestarrow-up-right](https://www.portainer.io/portainer-business-support)
  * Contribute to Portainer
    * [Contribute](https://docs.portainer.io/contribute/contribute)
    * [Build instructionschevron-right](https://docs.portainer.io/contribute/build)
  * [Privacy Policy](https://docs.portainer.io/privacy)


chevron-upchevron-down
xmark
block-quoteOn this pagechevron-down
  * [About Portainer](https://docs.portainer.io/#about-portainer)
  * [Documentation](https://docs.portainer.io/#documentation)
  * [Getting support](https://docs.portainer.io/#getting-support)
  * [Community Edition, Five/Three Node Free and Home & Student Users](https://docs.portainer.io/#community-edition-five-three-node-free-and-home-and-student-users)
  * [Business Edition Customers](https://docs.portainer.io/#business-edition-customers)


Was this helpful?
sun-brightdesktopmoon
chevron-down
# Welcome
Welcome to Portainer's official documentation site.
##
[hashtag](https://docs.portainer.io/#about-portainer)
About Portainer
**Portainer Community Edition (CE)** is our foundation. With over half a million regular users, CE is a powerful, open source toolset that allows you to easily build and manage containers in Docker, Docker Swarm, Kubernetes and Azure ACI.
**Portainer Business Edition (BE)** is our commercial offering. With features geared towards businesses and larger organizations such as [Role-Based Access Control](https://docs.portainer.io/admin/user/roles), [registry management](https://docs.portainer.io/admin/registries/browse), and [dedicated support](https://docs.portainer.io/#getting-support), Portainer BE is a powerful toolset that allows you to easily build and manage containers in Docker, Docker Swarm, Kubernetes, Podman and Azure ACI.
circle-info
Portainer Business Edition requires a license key to install and use. If you don't currently have a license key, you can [request three nodes freearrow-up-right](https://www.portainer.io/get-a-license) of Portainer Business Edition or [purchase a licensearrow-up-right](https://www.portainer.io/pricing).
Portainer hides the complexity of managing containers behind an easy-to-use UI. By removing the need to use the CLI, write YAML or understand manifests, Portainer makes deploying apps and troubleshooting problems so easy that anyone can do it.
Our team is here to help you on your journey. Community and five/three nodes free users can get assistance through our [community support channels](https://docs.portainer.io/#community-edition-five-three-node-free-and-home-and-student-users), and paid Business customers through our [business support channels](https://docs.portainer.io/#business-edition-customers).
##
[hashtag](https://docs.portainer.io/#documentation)
Documentation
We're working hard to ensure that our documentation keeps up with our ever-growing Portainer community. If you have a question we encourage you to start with the documentation (right here!). If you can't find what you're looking for, please raise a question in one of our [support channels](https://docs.portainer.io/#getting-support).
For more detailed step-by-step guides to Portainer, we're building out the [Portainer Academyarrow-up-right](https://academy.portainer.io) with more courses regularly.
circle-info
As an open source product we rely on users in our community to support one another by asking questions, engaging in discussions and sharing knowledge. Together with the documentation found on this site and our
##
[hashtag](https://docs.portainer.io/#getting-support)
Getting support
###
[hashtag](https://docs.portainer.io/#community-edition-five-three-node-free-and-home-and-student-users)
Community Edition, Five/Three Node Free and Home & Student Users
Community Edition, five/three nodes free and Home & Student users can get support through the following channels:
  * **Ask our AI bot** by clicking the **Ask AI** button in the bottom right of this documentation site. Our AI chatbot pulls from a number of sources and is a great place to start when looking for help.
  * **Ask questions** either in our [community Slack channelarrow-up-right](https://portainer.io/slack). Other platforms exist (Reddit, Discord, Stack Overflow) but we are less active in those spaces.
  * **Log bugs** in
  * **Flag vulnerabilities** by emailing
  * **Flag documentation issues** via our [contributing](https://docs.portainer.io/contribute/contribute) and make our documentation better!).


###
[hashtag](https://docs.portainer.io/#business-edition-customers)
Business Edition Customers
If you are a Professional or Enterprise tier Portainer Business Edition customer, you can log tickets directly with our team via [Request Support formarrow-up-right](https://www.portainer.io/portainer-business-support). You can report a bug, ask a question, tell us about an issue with documentation, or request a feature. Tickets are checked and resolved by Portainer staff within the SLA.
[NextWhat's new in version 2.39chevron-right](https://docs.portainer.io/whats-new)
Last updated 7 days ago
Was this helpful?
sun-brightdesktopmoon
This site uses cookies to deliver its service and to analyze traffic. By browsing this site, you accept the [privacy policy](https://www.portainer.io/privacy-policy).
close
AcceptReject
